diff --git a/modules/aeolus/aeolus_amv.py b/modules/aeolus/aeolus_amv.py
index 768f952f980179ba4ebf65ed36f8196767dd68ac..2ccb2f651a69c7efae65609a641e2f839dff30c5 100644
--- a/modules/aeolus/aeolus_amv.py
+++ b/modules/aeolus/aeolus_amv.py
@@ -1546,8 +1546,8 @@ def create_aeolus_clavrx_match_file(match_dct, filename, clvrx_params):
     grd_x_len = 9
     grd_y_len = 9
     num_aparams = 7
-    num_aprofs = len(match_dct)
     max_num_alevels = 0
+    num_aprofs = 0
 
     alons = []
     alats = []
@@ -1560,6 +1560,7 @@ def create_aeolus_clavrx_match_file(match_dct, filename, clvrx_params):
     for key in keys:
         tup_s = match_dct.get(key)
         for tup in tup_s:
+            num_aprofs += 1
             prof = tup[3]
             lat = prof[0, 0]
             lon = prof[0, 1]
@@ -1942,7 +1943,7 @@ def create_file_new(match_dct, filename, clvrx_params):
     elems = []
     lines = []
 
     # scan to get max num levels
     keys = list(match_dct.keys())
     for key in keys:
         tup_s = match_dct.get(key)
@@ -1960,6 +1961,11 @@ def create_file_new(match_dct, filename, clvrx_params):
             if nlevs > max_num_alevels:
                 max_num_alevels = nlevs
 
+            amvs = tup[4]
+            num_amvs = amvs.shape[1]
+            if num_amvs > max_num_amvs:
+                max_num_amvs = num_amvs
+
     alons = np.array(alons)
     alats = np.array(alats)
     atimes = np.array(atimes)
@@ -1942,7 +1943,7 @@ def create_file_new(match_dct, filename, clvrx_params):
     lines = []
 
-    # scan to get max num levels
+    # scan to get max num levels, amvs
     keys = list(match_dct.keys())
     for key in keys: